1.  Lipsum

    *   Ichi
    *   Ni
    *   San

2.  Lorem

    {image alt="numbered list" file-path="http://placehold.it/350x150" caption="false" source="https://placehold.it/" hover-text="This is hover text" alignment="left"}

3.  Ipsem
